/* Dia -- an diagram creation/manipulation program
 * Copyright (C) 1998 Alexander Larsson
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include "geometry.h"
#include "diagram.h"
#include "display.h"
#include "app_procs.h"
#include "group.h"

#include "load_save.h"
#include "interface.h"

int app_is_embedded(void)
{
  return 0;
}

int main(int argc, char *argv[])
{
  app_init(argc, argv);

  toolbox_show();
  
  gtk_main ();

  return 0;
}

